#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-gdkx11
version:                4.0.8
visibility:             public
id:                     gi-gdkx11-4.0.8-KjLMSjKOPrwF7X6TvJC7FI
key:                    gi-gdkx11-4.0.8-KjLMSjKOPrwF7X6TvJC7FI
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               GdkX11 bindings
description:            Bindings for GdkX11, autogenerated by haskell-gi.
category:               Bindings
abi:                    50eee2a80ca5b1f0479860f4f10a19bd
exposed:                True
exposed-modules:
    GI.GdkX11 GI.GdkX11.Config GI.GdkX11.Enums GI.GdkX11.Functions
    GI.GdkX11.Objects GI.GdkX11.Objects.X11AppLaunchContext
    GI.GdkX11.Objects.X11DeviceManagerXI2
    GI.GdkX11.Objects.X11DeviceXI2 GI.GdkX11.Objects.X11Display
    GI.GdkX11.Objects.X11Drag GI.GdkX11.Objects.X11GLContext
    GI.GdkX11.Objects.X11Monitor GI.GdkX11.Objects.X11Screen
    GI.GdkX11.Objects.X11Surface

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-gdkx11-4.0.8
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-gdkx11-4.0.8 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-gdkx11-4.0.8 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-gdkx11
hs-libraries:           HSgi-gdkx11-4.0.8-KjLMSjKOPrwF7X6TvJC7FI
extra-libraries:
    gtk-4 pangocairo-1.0 pango-1.0 harfbuzz gdk_pixbuf-2.0
    cairo-gobject cairo vulkan graphene-1.0 gio-2.0 gobject-2.0
    glib-2.0 X11

extra-libraries-static:
    gtk-4 pangocairo-1.0 m pangoft2-1.0 m pango-1.0 m fribidi thai
    datrie Xft harfbuzz-gobject harfbuzz m graphite2 gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 m pthread cairo-gobject m dl cairo m dl
    fontconfig m expat m freetype dl bz2 png16 m m brotlidec
    brotlicommon Xext Xrender xcb-render xcb-shm pixman-1 m vulkan
    graphene-1.0 m gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0 atomic
    m pcre2-8 pthread z mount blkid systemd sysprof-capture-4 X11
    pthread xcb Xau Xdmcp

include-dirs:
    /usr/include /usr/include/gtk-4.0 /usr/include/pango-1.0
    /usr/include/fribidi /usr/include/harfbuzz
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/cairo /usr/include/freetype2 /usr/include/libpng16
    /usr/include/pixman-1 /usr/include/graphene-1.0
    /usr/lib/graphene-1.0/include /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/libmount /usr/include/blkid
    /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-cairo-1.0.30-KvBXKA7Kp6yJ7AxspTj18j
    gi-gdk-4.0.9-F2Rq9Blm3hrKYwlK49eyVX
    gi-gio-2.0.38-BtT80M7hJyXGxvJ0OtpQrG
    gi-gobject-2.0.31-3A9RvIrJNMmKTi9mEMhnXb
    gi-xlib-2.0.14-G3Tr7OwDLu45bQRDRRY9CQ
    haskell-gi-0.26.17-LUbnxwr8mnB6jZ9E34J7wT
    haskell-gi-base-0.26.9-A51M6LjdiVN4RjdHJdLeji
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-gdkx11/html/gi-gdkx11.haddock
haddock-html:           /usr/share/doc/haskell-gi-gdkx11/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

